@@ -27,46 +27,13 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: adm.php,v 1.4 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: adm.php,v 1.5 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 error_reporting(E_ALL);
 
-// ʃvWFNg̐ݒt@C擾邽߂̏
-$is_project_dir = false;
-$is_app_name    = false;
-$config_file    = '';
-$app_name       = '';
-foreach ($argv as $arg) {
-    if ($is_project_dir) {
-        $config_file    = $arg . '/config/defines.xml';
-        $is_project_dir = false;
-    }
-    if ($is_app_name) {
-        $app_name    = $arg;
-        $is_app_name = false;
-    }
-    $is_project_dir = ($arg == '-d');
-    $is_app_name    = ($arg == '-w');
-}
-
-if ((array_search('-v', $argv) === false) &&
-    (array_search('-h', $argv) === false) &&
-    (array_search('--version', $argv) === false) &&
-    (array_search('--help',    $argv) === false)) {
-    if (!$config_file) {
-        echo "[SyL error] Project directory not found.\nTry `php {$argv[0]} --help' for more information.\n";
-        exit;
-    }
-    if (!$app_name) {
-        echo "[SyL error] Application name not found.\nTry `php {$argv[0]} --help' for more information.\n";
-        exit;
-    }
-}
-
-
 $syl_dir = dirname(dirname(__FILE__));
 
 require_once $syl_dir . '/SyL.php';
@@ -74,8 +41,7 @@ require_once $syl_dir . '/SyL.php';
 $config = array(
   'action_key'   => 'action',
   'project_dir'  => $syl_dir . '/opt/adm',
-  'app_name'     => 'generate',
-  'define_after' => $config_file
+  'app_name'     => 'generate'
 );
 
 $controller =& SyL_Controller::getController($config);
