@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.18 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.19 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,36 +39,69 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.18 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.19 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigDefines extends SyL_Config
 {
     /**
-     * ƥȤ򥻥å
-     * ƥȤʤΤ
+     * ե̾
+     * 
+     * @access private
+     * @var string
+     */
+    var $config_file_name = 'defines.xml';
+
+    /**
+     * ե򥻥å
      *
      * @access protected
-     * @param object ȥ饪֥
      */
-    function setContext(&$controller)
+    function setProjectConfigFiles()
     {
+        // ץꥱͤɤ߹
+        $config = SYL_APP_CONFIG_DIR . "/{$this->config_file_name}";
+        if (is_file($config)) {
+            $this->file_names[] = $config;
+        }
+        // Хͤɤ߹
+        $this->file_names[] = SYL_PROJECT_CONFIG_DIR . "/{$this->config_file_name}";
+    }
+
+    /**
+     * ե򥻥å
+     *
+     * @access public
+     * @param string or array եΥѥ
+     * @param bool ץե̵ե饰
+     */
+    function setConfigFiles($config, $this_only=true)
+    {
+        if ($this_only) {
+            $this->file_names = array();
+        }
+        if (!is_array($config)) {
+            $config = (array)$config;
+        }
+        $this->file_names = array_merge($this->file_names, $config);
     }
 
     /**
      * XMLեβϽ
      *
      * @access public
+     * @param bool åͭե饰
      */
-    function parseXml()
+    function parseXml($enable_cache=true)
     {
-        if (SYL_CACHE) {
+        if (SYL_CACHE && $enable_cache) {
             // åѤ
             $key = SYL_APP_DIR;
             $cache =& $this->getCache($key);
             if ($cache) {
                 // å夬Ǥʤäʥå奪֥Ȥ
                 parent::parseXml();
+                // å¸
                 $cache->write($this->config);
             }
         } else {
@@ -76,7 +109,7 @@ class SyL_ConfigDefines extends SyL_Config
             parent::parseXml();
         }
 
-        // 
+        // Ѵ
         $this->readConstants();
     }
 
@@ -103,10 +136,13 @@ class SyL_ConfigDefines extends SyL_Config
      */
     function readConstants()
     {
+        static $defined = false;
         foreach ($this->config as $key => $value) {
-            $value = preg_replace_callback('/\{(\w+)\}/', array(&$this, 'replaceConstant'), $value);
-            define($key, $value);
+            $value = preg_replace_callback('/\{(\w+)\}/', array(&$this, 'replaceConstants'), $value);
+            $this->config[$key] = $value;
+            if (!$defined) define($key, $value);
         }
+        $defined = true;
     }
 
     /**
@@ -116,9 +152,15 @@ class SyL_ConfigDefines extends SyL_Config
      * @param array ޥå
      @ return mixed ޥå
      */
-    function replaceConstant($matches)
+    function replaceConstants($matches)
     {
-        return defined($matches[1]) ? constant($matches[1]) : '{' . $matches[1] . '}';
+        if (isset($this->config[$matches[1]])) {
+            return $this->config[$matches[1]];
+        } else if (defined($matches[1])) {
+            return constant($matches[1]);
+        } else {
+            return '{' . $matches[1] . '}';
+        }
     }
 }
 
