@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.8 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.9 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'SyL_ContextJs.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.8 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.9 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextWeb extends SyL_ContextJs
@@ -85,7 +85,7 @@ class SyL_ContextWeb extends SyL_ContextJs
             $this->is_execute = false;
             $this->setViewType('js.default');
         } else {
-            $router =& SyL_Router::factory($controller, $data, SYL_ROUTER_RULE);
+            $router =& SyL_Router::factory($data, SYL_ROUTER_RULE);
             $this->setActionFile($router->getActionFile());
             $this->setClassName($router->getClassName());
             $this->setActionName($router->getActionName());
