@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.19 2008/02/02 14:40:44 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.20 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,11 +48,18 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_Cache.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.19 2008/02/02 14:40:44 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.20 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Config extends SyL_XmlReader
 {
+    /**
+     * ե̾
+     * 
+     * @access private
+     * @var string
+     */
+    var $config_file_name = '';
     /**
      * ٥̾
      * 
@@ -67,13 +74,6 @@ class SyL_Config extends SyL_XmlReader
      * @var int
      */
     var $default_priority = 5;
-    /**
-     * åǥ쥯ȥ̾
-     * 
-     * @access protected
-     * @var string
-     */
-    var $cache_dir_name = '';
     /**
      * ƥȥ֥
      * 
@@ -100,11 +100,19 @@ class SyL_Config extends SyL_XmlReader
      * 󥹥ȥ饯
      *
      * @access public
-     * @param mixed XMLե̾
      */
-    function SyL_Config($file_names)
+    function SyL_Config()
+    {
+        $this->setProjectConfigFiles();
+    }
+
+    /**
+     * ե򥻥å
+     *
+     * @access protected
+     */
+    function setProjectConfigFiles()
     {
-        $this->file_names = $file_names;
     }
 
     /**
@@ -113,30 +121,49 @@ class SyL_Config extends SyL_XmlReader
      * @static
      * @access public
      * @param string ե륪֥̾
-     * @param array ե̾
-     * @param object ȥ饪֥
-     * @param string ٥̾
      * @return object ե륪֥
      */
-    function &factory($config_name, $file_names, &$controller)
+    function &factory($config_name)
     {
         $class_name = 'SyL_Config' . ucfirst($config_name);
         include_once SYL_INCLUDE_DIR . "/framework/Config/{$class_name}.php";
-        $obj = new $class_name($file_names);
-        $obj->setContext($controller);
+        $obj = new $class_name();
         return $obj;
     }
 
     /**
      * ƥȤ򥻥å
      *
-     * @access protected
-     * @param object ȥ饪֥
+     * @access public
+     * @param object ƥȥ֥
      */
-    function setContext(&$controller)
+    function setContext(&$context)
     {
-        $container =& $controller->getContainer();
-        $this->context =& $container->getComponent('context');
+        $this->context =& $context;
+    }
+
+    /**
+     * ͤ
+     *
+     * @static
+     * @access public
+     * @param string ꥭ
+     */
+    function get($name='')
+    {
+        static $values = null;
+
+        if ($values !== null) {
+            if ($name === '') {
+                return $values;
+            } else {
+                return isset($values[$name]) ? $values[$name] : null;
+            }
+        } else {
+            $config =& SyL_Config::factory('defines');
+            $config->parseXml();
+            $values = $config->getConfig();
+        }
     }
 
     /**
@@ -163,7 +190,7 @@ class SyL_Config extends SyL_XmlReader
         $cache->setKey($key);
         $cache->setMinModifyTime($mtime);
         if (defined('SYL_CACHE_FILE_DIR') && SYL_CACHE_FILE_DIR) {
-            $cache->setCacheDir(SYL_CACHE_FILE_DIR . basename($this->file_names[0]) . '/');
+            $cache->setCacheDir(SYL_CACHE_FILE_DIR . SYL_APP_NAME . '/config/' . basename($this->file_names[0]) . '/');
         }
 
         //$cache->useIncludeCache();
@@ -183,8 +210,9 @@ class SyL_Config extends SyL_XmlReader
      * ʣXMLեϤ
      *
      * @access public
+     * @param bool åͭե饰
      */
-    function parseXml()
+    function parseXml($enable_cache=true)
     {
         $config = array();
         foreach ($this->file_names as $file_name) {
