@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.27 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.28 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.27 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.28 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -114,13 +114,13 @@ class SyL_Container
      * @param string ե
      * @param string ¹ԥݡͥ̾
      */
-    function raiseEvent($event, $config_type=array(), $component_name='')
+    function raiseEvent($event, $config_type='', $component_name='')
     {
         // ٥ȳϥ
         $this->log('debug', "{$event} event start");
 
         // եɤ߹
-        if (count($config_type) > 0) {
+        if ($config_type) {
             $this->config += $this->readConfig($config_type);
             // ̥ͥȽ
             uasort($this->config, array(&$this, 'sortConfig'));
@@ -326,13 +326,12 @@ echo "</pre>";
      */
     function readConfig($config_type)
     {
-        $config = array();
-        foreach ($config_type as $type => $file) {
-            $reader =& SyL_Config::factory($type, $file, $this->getComponent(SYL_CONTROLLER_NAME));
-            $reader->parseXml();
-            $config += $reader->getConfig();
+        $reader =& SyL_Config::factory($config_type);
+        if ($this->isComponent('context')) {
+            $reader->setContext($this->getComponent('context'));
         }
-        return $config;
+        $reader->parseXml();
+        return $reader->getConfig();
     }
 
     /**
