@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.18 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.19 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loader.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.18 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.19 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Context
@@ -112,7 +112,7 @@ class SyL_Context
      */
     function SyL_Context(&$controller, &$data)
     {
-        $router =& SyL_Router::factory($controller, $data, SYL_ROUTER_RULE);
+        $router =& SyL_Router::factory($data, SYL_ROUTER_RULE);
         $this->setActionFile($router->getActionFile());
         $this->setClassName($router->getClassName());
         $this->setActionName($router->getActionName());
