@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.33 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.34 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -52,11 +52,6 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  */
 require_once SYL_INCLUDE_DIR . '/framework/SyL_Container.php';
 
-/**
- * ƥ⥳ȥ̾
- */
-define('SYL_CONTROLLER_NAME', 'controller');
-
 /**
  * ȥ饯饹
  *
@@ -69,7 +64,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.33 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.34 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -88,34 +83,6 @@ class SyL_Controller
      * @var string
      */
     var $template_dir = '';
-    /**
-     * ե̾
-     *
-     * @access private
-     * @var string
-     */
-    var $defines_file_name = 'defines.xml';
-    /**
-     * ݡͥե̾
-     *
-     * @access protected
-     * @var string
-     */
-    var $components_file_name = 'components.xml';
-    /**
-     * ե륿ե̾
-     *
-     * @access private
-     * @var string
-     */
-    var $filter_file_name = 'filters.xml';
-    /**
-     * ե륿ե̾
-     *
-     * @access private
-     * @var string
-     */
-    var $action_file_name = 'actions.xml';
     /**
      * 顼ϥɥ᥽å̾
      * ''ξϥ顼ϥɥꤷʤ
@@ -180,8 +147,10 @@ class SyL_Controller
         define('SYL_PROJECT_CONFIG_DIR',  SYL_PROJECT_DIR . '/config');
         // ץȥ饤֥ǥ쥯ȥ
         define('SYL_PROJECT_LIB_DIR',  SYL_PROJECT_DIR . '/lib');
+        // ץꥱ̾
+        define('SYL_APP_NAME', $config['app_name']);
         // ץꥱǥ쥯ȥ
-        define('SYL_APP_DIR', SYL_PROJECT_DIR . '/apps/' . $config['app_name']);
+        define('SYL_APP_DIR', SYL_PROJECT_DIR . '/apps/' . SYL_APP_NAME);
         // ץꥱեǥ쥯ȥ
         define('SYL_APP_CONFIG_DIR', SYL_APP_DIR . '/config');
         // ץꥱ饤֥ǥ쥯ȥ
@@ -207,15 +176,7 @@ class SyL_Controller
         }
 
         // ɤ߹
-        if (isset($config['define_before']) && isset($config['define_after'])) {
-            $this->readDefines($config['define_before'], $config['define_after']);
-        } else if (isset($config['define_before']) && $config['define_before']) {
-            $this->readDefines($config['define_before'], '');
-        } else if (isset($config['define_after']) && $config['define_after']) {
-            $this->readDefines('', $config['define_after']);
-        } else {
-            $this->readDefines();
-        }
+        SyL_Config::get();
 
         // ǥ쥯ȥ
         $this->action_dir = SYL_APP_DIR . '/actions';
@@ -224,7 +185,7 @@ class SyL_Controller
 
         // ƥ
         $this->container =& SyL_Container::singleton();
-        $this->container->setComponent(SYL_CONTROLLER_NAME, $this);
+        $this->container->setComponent('controller', $this);
 
         // shutdownϥɥ
         if ($this->destory_handler_method != '') {
@@ -274,35 +235,6 @@ class SyL_Controller
         return $this->container;
     }
 
-    /**
-     * ɤ߹
-     *
-     * @access public
-     * @param array ɲե
-     */
-    function readDefines($define_before='', $define_after='')
-    {
-        $config_files = array();
-        // ɲե - ɤ߹
-        if ($define_before) {
-            $config_files[] = $define_before;
-        }
-         // ץꥱͤɤ߹
-        $config_files[] = SYL_APP_CONFIG_DIR . "/{$this->defines_file_name}";
-        if (!file_exists($config_files[0])) {
-            array_shift($config_files);
-        }
-        // Хͤɤ߹
-        $config_files[] = SYL_PROJECT_CONFIG_DIR . "/{$this->defines_file_name}";
-        // ɲե - ɤ߹
-        if ($define_after) {
-            $config_files[] = $define_after;
-        }
-
-        $config =& SyL_Config::factory('defines', $config_files, $this);
-        $config->parseXml();
-    }
-
     /**
      * 
      *
@@ -310,11 +242,8 @@ class SyL_Controller
      */
     function initStream()
     {
-        $config_files = array();
-        // Х륳ݡͥե
-        $config_files['components'][] = SYL_PROJECT_CONFIG_DIR . "/{$this->components_file_name}";
         // ٥ȼ¹
-        $this->raiseEvent('initStream', $config_files);
+        $this->raiseEvent('initStream', 'components');
 
         // ꥯȽ
         if (SYL_ENV_TYPE == 'cmd') {
@@ -335,24 +264,8 @@ class SyL_Controller
      */
     function loadStream()
     {
-        $config_files = array();
-        // ץꥱե륿ե
-        $filter = SYL_APP_CONFIG_DIR . "/{$this->filter_file_name}";
-        if (is_file($filter)) {
-            $config_files['filters'][] = $filter;
-        } else {
-            SyL_Loggers::info("filters app config file not found ({$filter})");
-        }
-        // Хե륿ե
-        $filter = SYL_PROJECT_CONFIG_DIR . "/{$this->filter_file_name}";
-        if (file_exists($filter)) {
-            $config_files['filters'][] = $filter;
-        } else {
-            SyL_Loggers::info("filters project config file not found ({$filter})");
-        }
-
         // ٥ȼ¹
-        $this->raiseEvent('loadStream', $config_files);
+        $this->raiseEvent('loadStream', 'filters');
     }
 
     /**
@@ -364,12 +277,8 @@ class SyL_Controller
     {
         $context =& $this->container->getComponent('context');
         if ($context->isExecute()) {
-            $config_files = array();
-            // ե
-            $config_files['actions'][] = SYL_APP_CONFIG_DIR . "/{$this->action_file_name}";
-
             // ٥ȼ¹
-            $this->raiseEvent('executeStream', $config_files);
+            $this->raiseEvent('executeStream', 'actions');
         }
     }
 
@@ -507,7 +416,7 @@ class SyL_Controller
      * @param string ٥ȥ᥽å̾
      * @param string ե̾
      */
-    function raiseEvent($event, $config_type=array())
+    function raiseEvent($event, $config_type='')
     {
         $this->container->raiseEvent($event, $config_type);
     }
