@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.20 2008/02/02 14:40:44 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.21 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,18 +39,11 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.20 2008/02/02 14:40:44 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.21 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Router
 {
-    /**
-     * 롼ƥե̾
-     * 
-     * @access private
-     * @param string
-     */
-    var $router_file_name = 'routers.xml';
     /**
      * ǥեȥե̾
      * Ƭʸ
@@ -131,12 +124,11 @@ class SyL_Router
      *
      * @static
      * @access public
-     * @param object ȥ饪֥
      * @param object ǡ֥
      * @param string ܾ󥪥֥̾
      * @return object ܾ󥪥֥
      */
-    function &factory(&$controller, &$data, $rule)
+    function &factory(&$data, $rule)
     {
         $classname = 'SyL_Router' . ucfirst($rule);
         include_once SYL_INCLUDE_DIR . "/framework/Router/{$classname}.php";
@@ -146,7 +138,7 @@ class SyL_Router
         if (!$router->validAction()) {
             SyL_Response::forward404();
         }
-        $router->changeRoutingConfig($controller);
+        $router->changeRoutingConfig();
         return $router;
     }
 
@@ -237,15 +229,9 @@ class SyL_Router
      * @param object ƥȥ֥
      * @param object ǡ֥
      */
-    function changeRoutingConfig(&$controller)
+    function changeRoutingConfig()
     {
-        $config_files = array();
-        $config_files[] = SYL_APP_CONFIG_DIR . "/{$this->router_file_name}";
-        if (!is_file($config_files[0])) {
-            return;
-        }
-
-        $config =& SyL_Config::factory('routers', $config_files, $controller);
+        $config =& SyL_Config::factory('routers');
         $config->parseXml();
         foreach ($config->getConfig() as $action => $router) {
             $action = str_replace('/', '\\/', $action); 
