@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.16 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.17 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_SMARTY_DIR . 'Smarty.class.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.16 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewSmarty.php,v 1.17 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewSmarty extends SyL_View
@@ -66,10 +66,17 @@ class SyL_ViewSmarty extends SyL_View
         parent::SyL_View($context, $data);
 
         $this->smarty =& new Smarty();
-        $this->smarty->compile_dir = SYL_SMARTY_COMPILE_DIR;
-        $this->smarty->config_dir  = SYL_SMARTY_CONFIG_DIR;
-        $this->smarty->cache_dir   = SYL_SMARTY_CACHE_DIR;
-        $this->smarty->compile_id  = basename(SYL_APP_DIR);
+        if (SYL_SMARTY_PROPERTIES) {
+            foreach(explode(';', SYL_SMARTY_PROPERTIES) as $properties) {
+                $tmp = explode('=', $properties, 2);
+                if (count($tmp) == 2) {
+                    list($name, $value) = $tmp;
+                    if (isset($this->smarty->$name)) {
+                        $this->smarty->$name = $value;
+                    }
+                }
+            }
+        }
     }
 
     /**
