@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_CacheDb.php,v 1.2 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_CacheDb.php,v 1.3 2008/03/29 06:11:46 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -65,7 +65,7 @@ require_once dirname(__FILE__) . '/../SyL_DB.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_CacheDb.php,v 1.2 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_CacheDb.php,v 1.3 2008/03/29 06:11:46 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_CacheDb extends SyL_Cache
@@ -128,6 +128,8 @@ class SyL_CacheDb extends SyL_Cache
      */
     function SyL_CacheDb()
     {
+        parent::SyL_Cache();
+
         if (!defined('SYL_CACHE_DB_TABLE')) {
             trigger_error("[SyL error] Undefined constant `SYL_CACHE_DB_TABLE'", E_USER_ERROR);
         }
@@ -176,15 +178,13 @@ class SyL_CacheDb extends SyL_Cache
             $mtime = time();
         }
 
-        $key = $this->getKey();
-
         $sql  = "";
         $sql .= "UPDATE ";
         $sql .=   "{$this->table} ";
         $sql .= "SET ";
         $sql .=   "{$this->timestamp} = {$mtime} ";
         $sql .= "WHERE ";
-        $sql .=   "{$this->id} = '{$key}' ";
+        $sql .=   "{$this->id} = '" . $this->conn->escape($this->getKey()) . "' ";
         return $this->conn->exec($sql);
     }
 
@@ -196,15 +196,13 @@ class SyL_CacheDb extends SyL_Cache
      */
     function getModifyTime()
     {
-        $key = $this->getKey();
-
         $sql  = "";
         $sql .= "SELECT ";
         $sql .=   "{$this->timestamp} ";
         $sql .= "FROM ";
         $sql .=   "{$this->table} ";
         $sql .= "WHERE ";
-        $sql .=   "{$this->id} = '{$key}' ";
+        $sql .=   "{$this->id} = '" . $this->conn->escape($this->getKey()) . "' ";
 
         $this->conn->queryRef($sql, $result, 'one');
         return $result;
@@ -219,8 +217,6 @@ class SyL_CacheDb extends SyL_Cache
      */
     function read($modify_time_update=false)
     {
-        $key = $this->getKey();
-
         $sql  = "";
         $sql .= "SELECT ";
         $sql .=   "{$this->data}, ";
@@ -228,7 +224,7 @@ class SyL_CacheDb extends SyL_Cache
         $sql .= "FROM ";
         $sql .=   "{$this->table} ";
         $sql .= "WHERE ";
-        $sql .=   "{$this->id} = '{$key}' ";
+        $sql .=   "{$this->id} = '" . $this->conn->escape($this->getKey()) . "' ";
 
         $this->conn->queryRef($sql, $result, 'record');
 
@@ -291,8 +287,6 @@ class SyL_CacheDb extends SyL_Cache
      */
     function write($data)
     {
-        $key = $this->getKey();
-
         // ǡΥꥢ벽Ƚ
         if ($this->serial) {
             $data = serialize($data);
@@ -308,7 +302,7 @@ class SyL_CacheDb extends SyL_Cache
         $sql .=   "{$this->timestamp}, ";
         $sql .=   "{$this->data} ";
         $sql .= ") VALUES ( ";
-        $sql .=   "'{$key}', ";
+        $sql .=   "'" . $this->conn->escape($this->getKey()) . "', ";
         $sql .=   " " . time() . ", ";
         $sql .=   "'" . $this->conn->escape($data) . "' ";
         $sql .= ") ";
@@ -324,13 +318,11 @@ class SyL_CacheDb extends SyL_Cache
      */
     function delete()
     {
-        $key = $this->getKey();
-
         $sql  = "";
         $sql .= "DELETE FROM ";
         $sql .=   "{$this->table} ";
         $sql .= "WHERE ";
-        $sql .=   "{$this->id} = '{$key}' ";
+        $sql .=   "{$this->id} = '" . $this->conn->escape($this->getKey()) . "' ";
         return $this->conn->exec($sql);
     }
 
@@ -341,16 +333,26 @@ class SyL_CacheDb extends SyL_Cache
      */
     function clean()
     {
+        if ($this->life_time == 0) {
+            return;
+        }
+
         $sql  = "";
         $sql .= "DELETE FROM ";
         $sql .=   "{$this->table} ";
         $sql .= "WHERE ";
+        $sql .= "(";
         $sql .= "(" . time() . " > {$this->timestamp} + {$this->life_time}) ";
         if ($this->min_mtime > 0) {
-            $sql .= "Or ({$this->timestamp} < {$this->min_mtime}) ";
+            $sql .= "OR ({$this->timestamp} < {$this->min_mtime}) ";
         }
         if ($this->max_mtime > 0) {
-            $sql .= "Or ({$this->timestamp} > {$this->max_mtime}) ";
+            $sql .= "OR ({$this->timestamp} > {$this->max_mtime}) ";
+        }
+        $sql .= ") ";
+
+        if ($this->prefix) {
+            $sql .= "AND ({$this->id} like '" . $this->conn->escape($this->prefix) . "%') ";
         }
         $this->conn->exec($sql);
     }
