@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_File.php,v 1.15 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_File.php,v 1.16 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ set_magic_quotes_runtime(0);
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_File.php,v 1.15 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_File.php,v 1.16 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_File
@@ -251,7 +251,7 @@ class SyL_File
      */
     function processAll($type, $resource_name, $message='')
     {
-        $file =& SYL_File::factory($type, $resource_name);
+        $file =& SyL_File::factory($type, $resource_name);
         switch (strtolower($type)) {
         case 'r':
             $message = $file->process();
