@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.3 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.4 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.3 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.4 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Index extends AppAction
@@ -128,7 +128,7 @@ class Index extends AppAction
     {
         $help = <<<EOF
 Usage:
-  php {$file} project [or pro] -d <dir> -w <name> [-c <file>]
+  php {$file} project [or pro] -d <dir> -w <name> [-c <file>] [-s <dir>]
   php {$file} application [or app] -d <dir> -w <name> [-c <file>]
   php {$file} controller [or con] -d <dir> -w <name> -c <file>
   php {$file} action [or act] -d <dir> -w <name> -a <name>
@@ -141,6 +141,7 @@ Options:
   -c <file> front controller file
   -a <name> action file (path from action directory)
   -t <name> template file (path from template directory)
+  -s <dir>  Smarty directory
   -h        show this help, then exit
   -v        output version information, then exit
 EOF;
