@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateApplication.php,v 1.6 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: CreateApplication.php,v 1.7 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateApplication.php,v 1.6 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: CreateApplication.php,v 1.7 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class CreateApplication
@@ -68,7 +68,12 @@ class CreateApplication
           'config'    => 0755,
           'lib'       => 0755,
           'lib/App'   => 0755,
-          'templates' => 0755
+          'templates' => 0755,
+          "../../var/cache/{$app_name}" => 0755,
+          "../../var/cache/{$app_name}/config" => 0777,
+          "../../var/logs/{$app_name}" => 0777,
+          "../../var/smarty/{$app_name}" => 0755,
+          "../../var/smarty/{$app_name}/templates_c" => 0777,
         );
 
         $files = array(
